@@ -7,4 +7,7 @@ class UserToken(models.Model):
 
     @property
     def is_sandbox(self):
-        return self.ebay_username.startswith('TESTUSER_')
\ No newline at end of file
+        return self.ebay_username.startswith('TESTUSER_')
+
+    def __unicode__(self):
+        return self.ebay_username
\ No newline at end of file
