@@ -21,10 +21,14 @@ class InvalidSignature(NotificationValidationError):
 
 
 class NotificationHandler(object):
-    def __init__(self, wsdl_url=WSDL_URL):
-        # TODO: should this take extra kwargs as EbaySuds does?
-        # eg make use of UserToken model
-        self.client = EbaySuds(wsdl_url)
+    def __init__(self, wsdl_url=WSDL_URL, token=None, sandbox=False):
+        es_kwargs = {
+            'wsdl_url': wsdl_url,
+            'sandbox': sandbox,
+        }
+        if token is not None:
+            es_kwargs['token'] = token
+        self.client = EbaySuds(**es_kwargs)
 
     def decode(self, payload_type, message):
         try:
@@ -60,8 +64,13 @@ class NotificationHandler(object):
         m = hashlib.md5()
         m.update(str(timestamp))
         m.update(ebaysuds_config.get('keys', 'dev_id'))
-        m.update(ebaysuds_config.get('keys', 'app_id'))
-        m.update(ebaysuds_config.get('keys', 'cert_id'))
+        if self.client.sandbox:
+            conf_section = 'sandbox_keys'
+        else:
+            conf_section = 'production_keys'
+        # sandbox?  
+        m.update(ebaysuds_config.get(conf_section, 'app_id'))
+        m.update(ebaysuds_config.get(conf_section, 'cert_id'))
         computed_hash = base64.standard_b64encode(m.hexdigest())
         if computed_hash != message.RequesterCredentials.NotificationSignature:
             raise InvalidSignature(message.RequesterCredentials.NotificationSignature)
