@@ -38,7 +38,7 @@ def notification(request, username=None):
     if settings.DEBUG:
         with open('last_request.pkl', 'wb') as output:
             meta = dict([(k,v) for k,v in request.META.items() if isinstance(v, basestring)])
-            obj = {'META': meta, 'body': request.body)}
+            obj = {'META': meta, 'body': request.body}
             pickle.dump(obj, output)
     
     try:
